Sinergym
--------

This section describes the singergym integration in beobench.

Resources
^^^^^^^^^

- Repository: https://github.com/jajimer/sinergym/
- Documentation: https://jajimer.github.io/sinergym/

Licensing
^^^^^^^^^

All code is covered by the standard beobench_contrib license apart from the dockerfile in the ``beobench_contrib/sinergym`` folder. This dockerfile contains code that is licensed under the LICENSE provided in that folder.